/* ================================================================================================================================
  Christian Thomas July 2021 adapted from Andrew Pericak, July 2016
  
  This script will create GEE Export tasks for you to download R-G-B-NIR imagery from Landsat and NAIP, to match the years used 
  in the MTM analysis scripts. This imagery can then be used for running the accuracy assessment. Note that Landsat covers all 
  years, but that NAIP only starts in 2006, and it only selectively covers some states each year. This script will export imagery 
  only falling directly underneath given sample areas (plots), plus a 1 km buffer around those sample plots.
  
  This code is updated from the code available in the 2021_MTM_Footprint folder, the C01/T1 Landsat Collections are now deprecated,
  this code makes use of C02/T1 collections. It also adds Landsat 9 to the collection. Outputs are writted to the same collections
  as those used in 2021_MTM_Footprint, although this is only to add data from 2022 onwards.
-----------------------------------------------------------------------------------------------------------------------------------
	The methodology of the MTM data produced for PLOS One relied on the now deprecated Pre-Collection Landsat data. The USGS 
	Switched to the Collection format around May 2017. This change has prompted a shift to use USGS Landsat Collection 1 Tier 1 and 
	Real-Time Raw Scenes, and is reflected here. Read about the original study here: 
	https://journals.plos.org/plosone/article?id=10.1371/journal.pone.0197758
================================================================================================================================ */

// CHANGE THE YEAR for whatever year you need imagery
var year = 2021;  // 1984-2022

// var sampleAreas = ee.FeatureCollection('users/skytruth-data/MTR/AccuracyAreas/used_Accuracy_Areas');
var sampleAreas = ee.FeatureCollection('users/skytruth-data/MTR/AccuracyAreas/All_Accuracy_Areas_4326').filter(ee.Filter.inList('UNIQUE_ID',[246,242,227,208,207,205,183,182,148,146,124,91,86,30]));
// Map.addLayer(sampleAreasx)
var sampleAreaBuffer = sampleAreas.geometry().buffer(1000); // Sample areas buffered 1 km to get surroundings
var exportbounds = sampleAreaBuffer.bounds();

/* ---------------------------------------------- LANDSAT EXPORTING ------------------------------------------------------------ */
// These if-else if statements will select the proper imagery based on whatever year you're looking at and run the TOA conversion, 
// and then a median filter (per the GEE tutorials; they look nice.)

if (year > 1983 && year <= 2011){
  var LSimagery = ee.Image(ee.ImageCollection("LANDSAT/LT05/C02/T1_TOA")  // Landsat 5: 1984 - 2011
    .filterDate(year+"-01-01", year+"-12-31")
    .filterMetadata("CLOUD_COVER", "less_than", 10)
    .map(function(image){
      var clipped = image.clip(sampleAreaBuffer);
      return clipped.select("B1","B2","B3","B4");
    })
    .median());
    // .reduce(ee.Reducer.percentile([15])));
}

else if (year == 2012){
  var LSimagery = ee.Image(ee.ImageCollection("LANDSAT/LE07/C02/T1_TOA")  // Landsat 7: 2012
    .filterDate(year+"-01-01", year+"-12-31")
    .filterMetadata("CLOUD_COVER", "less_than", 10)
    .map(function(image){
      var clipped = image.clip(sampleAreaBuffer);
      return clipped.select("B1","B2","B3","B4");
    })
    .median());
    // .reduce(ee.Reducer.percentile([15])));
}

else if (year >= 2013 && year <= 2022){
  var LSimagery = ee.Image(ee.ImageCollection("LANDSAT/LC08/C02/T1_TOA")  // Landsat 8: 2013 - 
    .filterDate(year+"-01-01", year+"-12-31")
    .filterMetadata("CLOUD_COVER", "less_than", 10)
    .map(function(image){
      var clipped = image.clip(sampleAreaBuffer);
      return clipped.select("B2","B3","B4","B5");
    })
    // .median());
    .reduce(ee.Reducer.percentile([15])));
}

else if (year >= 2022){
  var LSimagery_l8 = ee.ImageCollection("LANDSAT/LC08/C02/T1_TOA")
    .filterDate(year+"-01-01", year+"-12-31")
    .filterMetadata("CLOUD_COVER", "less_than", 10)
    .map(function(image){
      var clipped = image.clip(sampleAreaBuffer);
      return clipped.select("B2","B3","B4","B5");
    });
  var LSimagery_l9 = ee.ImageCollection("LANDSAT/LC09/C02/T1_TOA")
    .filterDate(year+"-01-01", year+"-12-31")
    .filterMetadata("CLOUD_COVER", "less_than", 10)
    .map(function(image){
      var clipped = image.clip(sampleAreaBuffer);
      return clipped.select("B2","B3","B4","B5");
    });
  
  var LSimagery = ee.Image(ee.ImageCollection((LSimagery_l8).merge(LSimagery_l9)).median());
  // var LSimagery = ee.Image(ee.ImageCollection((LSimagery_l8).merge(LSimagery_l9)).reduce(ee.Reducer.percentile([15])));
}


// This exports the Landsat imagery
Export.image.toDrive({
  image: LSimagery,
  // description: "Accuracy_MEDIAN_Landsat_"+year,
  description: "Accuracy_PCT15_Landsat_"+year,
  region: exportbounds,
  scale: 30,
  crs: "EPSG:5072",
  maxPixels: 1e10,
  folder: "MTM_LANDSAT_IMAGES"  // Whatever GDrive folder you're using; note you don't need a "file path"
});

// Map.addLayer(LSimagery,{bands:['B4','B3','B2'],min:0.03,max:0.25},'TOA '+year);
Map.addLayer(LSimagery,{bands:['B4_p15','B3_p15','B2_p15'],min:0.03,max:0.25},'TOA '+year);

// // --------------------------------------------- NAIP EXPORTNG -------------------------------------------------------------------- 

// // 2016, 2014, 2012 (partial), 2011 (partial), 2010 (partial), 2009 (partial), 2008 (partial), 2007 (partial), 2005 (partial), 
// var naip_year = 2020;
// var naip = ee.ImageCollection("USDA/NAIP/DOQQ").select('R', 'G', 'B').filterDate(naip_year+'-01-01', naip_year+'-12-31').mosaic().clip(sampleAreaBuffer);
// Map.addLayer(naip, {min:0,max:255},'NAIP '+naip_year);

// Export.image.toDrive({
//   image: naip,
//   description: "NAIP_"+naip_year,
//   region: exportbounds,
//   scale: 1,
//   crs: "EPSG:4326",
//   maxPixels: 1e11,
//   folder: "MTM_LANDSAT_IMAGES"
// });